Module cnn

Module cnn 

Convolutional neural network for Atari games.

The architecture is the same in the DQN Nature paper. It should be noted that the input array will be scaled by 1 / 255 for normalizing pixel intensities with casting from u8 to f32.

Structs

AtariCnn
Convolutional neural network for Atari games, which has the same architecture of the DQN paper.
AtariCnnConfig
Configuration of AtariCnn.