pub struct DqnConfig<Q>where
Q: SubModel<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,{Show 15 fields
pub model_config: DqnModelConfig<Q::Config>,
pub soft_update_interval: usize,
pub n_updates_per_opt: usize,
pub batch_size: usize,
pub discount_factor: f64,
pub tau: f64,
pub train: bool,
pub explorer: DqnExplorer,
pub clip_reward: Option<f64>,
pub double_dqn: bool,
pub clip_td_err: Option<(f64, f64)>,
pub device: Option<Device>,
pub critic_loss: CriticLoss,
pub record_verbose_level: usize,
pub phantom: PhantomData<Q>,
}Expand description
Configuration of Dqn agent.
Fields
model_config: DqnModelConfig<Q::Config>soft_update_interval: usizen_updates_per_opt: usizebatch_size: usizediscount_factor: f64tau: f64train: boolexplorer: DqnExplorerclip_reward: Option<f64>double_dqn: boolclip_td_err: Option<(f64, f64)>device: Option<Device>critic_loss: CriticLossrecord_verbose_level: usizephantom: PhantomData<Q>Implementations
Sourceimpl<Q> DqnConfig<Q>
impl<Q> DqnConfig<Q>
Sourcepub fn soft_update_interval(self, v: usize) -> Self
pub fn soft_update_interval(self, v: usize) -> Self
Sets soft update interval.
Sourcepub fn n_updates_per_opt(self, v: usize) -> Self
pub fn n_updates_per_opt(self, v: usize) -> Self
Sets the numper of parameter update steps per optimization step.
Sourcepub fn batch_size(self, v: usize) -> Self
pub fn batch_size(self, v: usize) -> Self
Batch size.
Sourcepub fn discount_factor(self, v: f64) -> Self
pub fn discount_factor(self, v: f64) -> Self
Discount factor.
Sourcepub fn explorer(self, v: DqnExplorer) -> Self
pub fn explorer(self, v: DqnExplorer) -> Self
Explorer.
Sourcepub fn model_config(self, model_config: DqnModelConfig<Q::Config>) -> Self
pub fn model_config(self, model_config: DqnModelConfig<Q::Config>) -> Self
Sets the configuration of the model.
Sourcepub fn opt_config(self, opt_config: OptimizerConfig) -> Self
pub fn opt_config(self, opt_config: OptimizerConfig) -> Self
Sets the configration of the optimizer.
Sourcepub fn out_dim(self, out_dim: i64) -> Self
pub fn out_dim(self, out_dim: i64) -> Self
Sets the output dimention of the dqn model of the DQN agent.
Sourcepub fn clip_reward(self, clip_reward: Option<f64>) -> Self
pub fn clip_reward(self, clip_reward: Option<f64>) -> Self
Reward clipping.
Sourcepub fn double_dqn(self, double_dqn: bool) -> Self
pub fn double_dqn(self, double_dqn: bool) -> Self
Double DQN
Sourcepub fn clip_td_err(self, clip_td_err: Option<(f64, f64)>) -> Self
pub fn clip_td_err(self, clip_td_err: Option<(f64, f64)>) -> Self
TD-error clipping.
Sourcepub fn critic_loss(self, v: CriticLoss) -> Self
pub fn critic_loss(self, v: CriticLoss) -> Self
Sets critic loss.
Sourcepub fn record_verbose_level(self, v: usize) -> Self
pub fn record_verbose_level(self, v: usize) -> Self
Sets verbose level.