DqnModel

Struct DqnModel 

pub struct DqnModel<Q>
where Q: SubModel<Output = Tensor>, Q::Config: DeserializeOwned + Serialize + OutDim,
{ /* private fields */ }
Action value function model for DQN.

The architecture of the model is defined by the type parameter Q, which should implement SubModel. This takes SubModel::Input as input and outputs a tensor. The output tensor should have the same dimension as the number of actions.

Implementations

Source

impl<Q> DqnModel<Q>
where Q: SubModel<Output = Tensor>, Q::Config: DeserializeOwned + Serialize + OutDim,

pub fn build(config: DqnModelConfig<Q::Config>, device: Device) -> Self

pub fn forward(&self, x: &Q::Input) -> Tensor

Outputs the action-value given observation(s).

pub fn param_stats(&self) -> Record