pub struct EpsilonGreedy {
pub n_opts: usize,
pub eps_start: f64,
pub eps_final: f64,
pub final_step: usize,
}Expand description
Epsilon-greedy explorer for DQN.
Fields
n_opts: usizeeps_start: f64eps_final: f64final_step: usizeImplementations
Sourceimpl EpsilonGreedy
impl EpsilonGreedy
Sourcepub fn with_final_step(final_step: usize) -> DqnExplorer
pub fn with_final_step(final_step: usize) -> DqnExplorer
Constructs epsilon-greedy explorer.
TODO: improve interface.
Sourcepub fn action(&mut self, a: &Tensor) -> Tensor
pub fn action(&mut self, a: &Tensor) -> Tensor
Takes an action based on the observation and the critic.
Sourcepub fn action_with_best(&mut self, a: &Tensor) -> (Tensor, bool)
pub fn action_with_best(&mut self, a: &Tensor) -> (Tensor, bool)
Takes an action based on the observation and the critic.