IqnModelConfig

Struct IqnModelConfig 

pub struct IqnModelConfig<F, M>
where M: OutDim,
{ pub feature_dim: i64, pub embed_dim: i64, pub f_config: Option<F>, pub m_config: Option<M>, pub opt_config: OptimizerConfig, }
Configuration of IqnModel.

The type parameter F represents a configuration struct of a feature extractor. The type parameter M represents a configuration struct of a model for merging cosine-embedded percent points and feature vectors.

Fields

feature_dim: i64

Dimension of feature vector.

embed_dim: i64

Embedding dimension.

f_config: Option<F>

Configuration of feature extractor.

m_config: Option<M>

Configuration of a model for merging percentils and feature vectors.

opt_config: OptimizerConfig

Configuration of optimizer.

Implementations

Source

impl<F, M> IqnModelConfig<F, M>

pub fn learning_rate(self, v: f64) -> Self

Sets the learning rate.

Source

impl<F, M> IqnModelConfig<F, M>

pub fn embed_dim(self, v: i64) -> Self

Sets the dimension of cos-embedding of percent points.

pub fn feature_dim(self, v: i64) -> Self

Sets the dimension of feature vectors.

pub fn f_config(self, v: F) -> Self

Sets configurations for feature extractor.

pub fn m_config(self, v: M) -> Self

Sets configurations for output model.

pub fn out_dim(self, out_dim: i64) -> Self

Sets output dimension of the model.

pub fn opt_config(self, v: OptimizerConfig) -> Self

Sets optimizer configuration.

pub fn load(path: impl AsRef<Path>) -> Result<Self>

Constructs IqnModelConfig from YAML file.

pub fn save(&self, path: impl AsRef<Path>) -> Result<()>