Module model

Interface of neural networks used in RL agents.

Traits

ModelBase
Base interface.
SubModel
Neural network model that can be initialized with VarStore and configuration.
SubModel2
Neural network model that can be initialized with VarStore and configuration.