pub struct EntCoef { /* private fields */ }
The entropy coefficient of SAC.
Constructs an instance of EntCoef.
Returns the entropy coefficient.
Does an optimization step given a loss.
Update the parameter given an action probability vector.
Save the parameter into a file.
Save the parameter from a file.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,