Struct border_tch_agent::sac::SACConfig
source · [−]pub struct SACConfig<Q, P> where
Q: SubModel2<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P: SubModel<Output = (Tensor, Tensor)>,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone, {
pub device: Option<Device>,
/* private fields */
}Expand description
Constructs SAC.
Fields
device: Option<Device>Implementations
Sets the numper of parameter update steps per optimization step.
Interval before starting optimization.
Batch size.
Discount factor.
SAC-alpha.
Replay buffer capacity.
Reward scale.
It works for obtaining target values, not the values in logs.
Critic loss.
Configuration of actor.
Configuration of critic.