SacConfig

Struct SacConfig 

pub struct SacConfig<Q, P>{
Show 16 fields pub actor_config: ActorConfig<P::Config>, pub critic_config: CriticConfig<Q::Config>, pub gamma: f64, pub tau: f64, pub ent_coef_mode: EntCoefMode, pub epsilon: f64, pub min_lstd: f64, pub max_lstd: f64, pub n_updates_per_opt: usize, pub batch_size: usize, pub train: bool, pub critic_loss: CriticLoss, pub reward_scale: f32, pub n_critics: usize, pub seed: Option<i64>, pub device: Option<Device>,
}
Configuration of Sac.

Fields

actor_config: ActorConfig<P::Config>critic_config: CriticConfig<Q::Config>gamma: f64tau: f64ent_coef_mode: EntCoefModeepsilon: f64min_lstd: f64max_lstd: f64n_updates_per_opt: usizebatch_size: usizetrain: boolcritic_loss: CriticLossreward_scale: f32n_critics: usizeseed: Option<i64>device: Option<Device>

Implementations

Source

impl<Q, P> SacConfig<Q, P>

pub fn n_updates_per_opt(self, v: usize) -> Self

Sets the numper of parameter update steps per optimization step.

pub fn batch_size(self, v: usize) -> Self

Batch size.

pub fn discount_factor(self, v: f64) -> Self

Discount factor.

pub fn tau(self, v: f64) -> Self

Sets soft update coefficient.

pub fn ent_coef_mode(self, v: EntCoefMode) -> Self

SAC-alpha.

pub fn reward_scale(self, v: f32) -> Self

Reward scale.

It works for obtaining target values, not the values in logs.

pub fn critic_loss(self, v: CriticLoss) -> Self

Critic loss.

pub fn actor_config(self, actor_config: ActorConfig<P::Config>) -> Self

Configuration of actor.

pub fn critic_config(self, critic_config: CriticConfig<Q::Config>) -> Self

Configuration of critic.

pub fn n_critics(self, n_critics: usize) -> Self

The number of critics.

pub fn seed(self, seed: i64) -> Self

Random seed.

pub fn device(self, device: Device) -> Self

Device.

pub fn load(path: impl AsRef<Path>) -> Result<Self>

Constructs SacConfig from YAML file.

pub fn save(&self, path: impl AsRef<Path>) -> Result<()>

Saves SacConfig.