Module util

Module util 

Utilities.

Structs

NamedTensors
Named tensors to send model parameters using a channel.

Enums

CriticLoss
Critic loss type.

Traits

OutDim
Interface for handling output dimensions.

Functions

arrayd_to_tensor
Converts ndarray::ArrayD to Tensor.
concat_slices
Concatenates slices.
param_stats
Returns the mean and standard deviation of the parameters.
quantile_huber_loss
Returns the quantile huber loss.
tensor_to_arrayd
Converts Tensor to ndarray::ArrayD.
track
Apply soft update on variables.
vec_to_tensor