Module border_tch_agent::cnn

source ·
Convolutional neural network.

The architecture is the same in the DQN Nature paper. It should be noted that the input array will be scaled by 1 / 255 for normalizing pixel intensities with casting from u8 to f32.

Structs

  • Convolutional neural network, which has the same architecture of the DQN paper.
  • Configuration of Cnn.