pub struct DqnConfig<Q>where
    Q: SubModel<Output = Tensor>,
    Q::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,{
    pub device: Option<Device>,
    /* private fields */
}
Configuration of Dqn agent.

Fields

device: Option<Device>

Implementations

source

impl<Q> DqnConfig<Q>where Q: SubModel<Output = Tensor>, Q::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,

source

pub fn soft_update_interval(self, v: usize) -> Self

Sets soft update interval.

source

pub fn n_updates_per_opt(self, v: usize) -> Self

Sets the numper of parameter update steps per optimization step.

source

pub fn min_transitions_warmup(self, v: usize) -> Self

Interval before starting optimization.

source

pub fn batch_size(self, v: usize) -> Self

Batch size.

source

pub fn discount_factor(self, v: f64) -> Self

Discount factor.

source

pub fn tau(self, v: f64) -> Self

Soft update coefficient.

source

pub fn explorer(self, v: DqnExplorer) -> Self

Explorer.

source

pub fn model_config(self, model_config: DqnModelConfig<Q::Config>) -> Self

Sets the configuration of the model.

source

pub fn out_dim(self, out_dim: i64) -> Self

Sets the output dimention of the dqn model of the DQN agent.

source

pub fn clip_reward(self, clip_reward: Option<f64>) -> Self

Reward clipping.

source

pub fn double_dqn(self, double_dqn: bool) -> Self

Double DQN

source

pub fn clip_td_err(self, clip_td_err: Option<(f64, f64)>) -> Self

TD-error clipping.

source

pub fn device(self, device: Device) -> Self

Device.

source

pub fn load(path: impl AsRef<Path>) -> Result<Self>

Loads DqnConfig from YAML file.

source

pub fn save(&self, path: impl AsRef<Path>) -> Result<()>

Saves DqnConfig.