Struct border_tch_agent::dqn::DqnConfig
source · pub struct DqnConfig<Q>where
Q: SubModel<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,{
pub device: Option<Device>,
/* private fields */
}Expand description
Configuration of Dqn agent.
Fields
device: Option<Device>Implementations
sourceimpl<Q> DqnConfig<Q>where
Q: SubModel<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
impl<Q> DqnConfig<Q>where Q: SubModel<Output = Tensor>, Q::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
sourcepub fn soft_update_interval(self, v: usize) -> Self
pub fn soft_update_interval(self, v: usize) -> Self
Sets soft update interval.
sourcepub fn n_updates_per_opt(self, v: usize) -> Self
pub fn n_updates_per_opt(self, v: usize) -> Self
Sets the numper of parameter update steps per optimization step.
sourcepub fn min_transitions_warmup(self, v: usize) -> Self
pub fn min_transitions_warmup(self, v: usize) -> Self
Interval before starting optimization.
sourcepub fn batch_size(self, v: usize) -> Self
pub fn batch_size(self, v: usize) -> Self
Batch size.
sourcepub fn discount_factor(self, v: f64) -> Self
pub fn discount_factor(self, v: f64) -> Self
Discount factor.
sourcepub fn explorer(self, v: DqnExplorer) -> Self
pub fn explorer(self, v: DqnExplorer) -> Self
Explorer.
sourcepub fn model_config(self, model_config: DqnModelConfig<Q::Config>) -> Self
pub fn model_config(self, model_config: DqnModelConfig<Q::Config>) -> Self
Sets the configuration of the model.
sourcepub fn out_dim(self, out_dim: i64) -> Self
pub fn out_dim(self, out_dim: i64) -> Self
Sets the output dimention of the dqn model of the DQN agent.
sourcepub fn clip_reward(self, clip_reward: Option<f64>) -> Self
pub fn clip_reward(self, clip_reward: Option<f64>) -> Self
Reward clipping.
sourcepub fn double_dqn(self, double_dqn: bool) -> Self
pub fn double_dqn(self, double_dqn: bool) -> Self
Double DQN
sourcepub fn clip_td_err(self, clip_td_err: Option<(f64, f64)>) -> Self
pub fn clip_td_err(self, clip_td_err: Option<(f64, f64)>) -> Self
TD-error clipping.