pub struct DqnModel<Q>{ /* private fields */ }Expand description
Action value function model for DQN.
The architecture of the model is defined by the type parameter Q,
which should implement SubModel.
This takes SubModel::Input as input and outputs a tensor.
The output tensor should have the same dimension as the number of actions.
Implementations