pub struct IqnModelConfig<F, M>where
M: OutDim,{
pub feature_dim: i64,
pub embed_dim: i64,
pub f_config: Option<F>,
pub m_config: Option<M>,
pub opt_config: OptimizerConfig,
}Expand description
Configuration of IqnModel.
The type parameter F represents a configuration struct of a feature extractor.
The type parameter M represents a configuration struct of a model for merging
cosine-embedded percent points and feature vectors.
Fields
feature_dim: i64Dimension of feature vector.
embed_dim: i64Embedding dimension.
f_config: Option<F>Configuration of feature extractor.
m_config: Option<M>Configuration of a model for merging percentils and feature vectors.
opt_config: OptimizerConfigConfiguration of optimizer.
Implementations
Sourceimpl<F, M> IqnModelConfig<F, M>
impl<F, M> IqnModelConfig<F, M>
Sourcepub fn learning_rate(self, v: f64) -> Self
pub fn learning_rate(self, v: f64) -> Self
Sets the learning rate.
Sourceimpl<F, M> IqnModelConfig<F, M>
impl<F, M> IqnModelConfig<F, M>
Sourcepub fn feature_dim(self, v: i64) -> Self
pub fn feature_dim(self, v: i64) -> Self
Sets the dimension of feature vectors.
Sourcepub fn opt_config(self, v: OptimizerConfig) -> Self
pub fn opt_config(self, v: OptimizerConfig) -> Self
Sets optimizer configuration.