pub struct IqnModelConfig<F, M>where
    M: OutDim,{
    pub feature_dim: i64,
    pub embed_dim: i64,
    pub f_config: Option<F>,
    pub m_config: Option<M>,
    pub opt_config: OptimizerConfig,
}
Configuration of IqnModel.

The type parameter F represents a configuration struct of a feature extractor. The type parameter M represents a configuration struct of a model for merging cosine-embedded percent points and feature vectors.

Fields

feature_dim: i64

Dimension of feature vector.

embed_dim: i64

Embedding dimension.

f_config: Option<F>

Configuration of feature extractor.

m_config: Option<M>

Configuration of a model for merging percentils and feature vectors.

opt_config: OptimizerConfig

Configuration of optimizer.

Implementations

source

impl<F, M> IqnModelConfig<F, M>where F: DeserializeOwned + Serialize, M: DeserializeOwned + Serialize + OutDim,

source

pub fn learning_rate(self, v: f64) -> Self

Sets the learning rate.

source

impl<F, M> IqnModelConfig<F, M>where F: DeserializeOwned + Serialize, M: DeserializeOwned + Serialize + OutDim,

source

pub fn embed_dim(self, v: i64) -> Self

Sets the dimension of cos-embedding of percent points.

source

pub fn feature_dim(self, v: i64) -> Self

Sets the dimension of feature vectors.

source

pub fn f_config(self, v: F) -> Self

Sets configurations for feature extractor.

source

pub fn m_config(self, v: M) -> Self

Sets configurations for output model.

source

pub fn out_dim(self, out_dim: i64) -> Self

Sets output dimension of the model.

source

pub fn opt_config(self, v: OptimizerConfig) -> Self

Sets optimizer configuration.

source

pub fn load(path: impl AsRef<Path>) -> Result<Self>

Constructs IqnModelConfig from YAML file.

source

pub fn save(&self, path: impl AsRef<Path>) -> Result<()>