pub struct IqnModelConfig<F, M> where
    M: OutDim
{ pub feature_dim: i64, pub embed_dim: i64, pub f_config: Option<F>, pub m_config: Option<M>, pub opt_config: OptimizerConfig, }
Configuration of IqnModel.

The type parameter F represents a configuration struct of a feature extractor. The type parameter M represents a configuration struct of a model for merging cosine-embedded percent points and feature vectors.

Fields

feature_dim: i64

Dimension of feature vector.

embed_dim: i64

Embedding dimension.

f_config: Option<F>

Configuration of feature extractor.

m_config: Option<M>

Configuration of a model for merging percentils and feature vectors.

opt_config: OptimizerConfig

Configuration of optimizer.

Implementations

Sets the learning rate.

Sets the dimension of cos-embedding of percent points.

Sets the dimension of feature vectors.

Sets configurations for feature extractor.

Sets configurations for output model.

Sets output dimension of the model.

Sets optimizer configuration.

Constructs IqnModelConfig from YAML file.