Interface of neural networks used in RL agents.

Traits

Base interface.

Neural network model that can be initialized with VarStore and configuration.

Neural network model that can be initialized with VarStore and configuration.