pub struct SacConfig<Q, P>where
Q: SubModel2<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P: SubModel<Output = (Tensor, Tensor)>,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,{Show 16 fields
pub actor_config: ActorConfig<P::Config>,
pub critic_config: CriticConfig<Q::Config>,
pub gamma: f64,
pub tau: f64,
pub ent_coef_mode: EntCoefMode,
pub epsilon: f64,
pub min_lstd: f64,
pub max_lstd: f64,
pub n_updates_per_opt: usize,
pub batch_size: usize,
pub train: bool,
pub critic_loss: CriticLoss,
pub reward_scale: f32,
pub n_critics: usize,
pub seed: Option<i64>,
pub device: Option<Device>,
}Expand description
Configuration of Sac.
Fields
actor_config: ActorConfig<P::Config>critic_config: CriticConfig<Q::Config>gamma: f64tau: f64ent_coef_mode: EntCoefModeepsilon: f64min_lstd: f64max_lstd: f64n_updates_per_opt: usizebatch_size: usizetrain: boolcritic_loss: CriticLossreward_scale: f32n_critics: usizeseed: Option<i64>device: Option<Device>Implementations
Sourceimpl<Q, P> SacConfig<Q, P>
impl<Q, P> SacConfig<Q, P>
Sourcepub fn n_updates_per_opt(self, v: usize) -> Self
pub fn n_updates_per_opt(self, v: usize) -> Self
Sets the numper of parameter update steps per optimization step.
Sourcepub fn batch_size(self, v: usize) -> Self
pub fn batch_size(self, v: usize) -> Self
Batch size.
Sourcepub fn discount_factor(self, v: f64) -> Self
pub fn discount_factor(self, v: f64) -> Self
Discount factor.
Sourcepub fn ent_coef_mode(self, v: EntCoefMode) -> Self
pub fn ent_coef_mode(self, v: EntCoefMode) -> Self
SAC-alpha.
Sourcepub fn reward_scale(self, v: f32) -> Self
pub fn reward_scale(self, v: f32) -> Self
Reward scale.
It works for obtaining target values, not the values in logs.
Sourcepub fn critic_loss(self, v: CriticLoss) -> Self
pub fn critic_loss(self, v: CriticLoss) -> Self
Critic loss.
Sourcepub fn actor_config(self, actor_config: ActorConfig<P::Config>) -> Self
pub fn actor_config(self, actor_config: ActorConfig<P::Config>) -> Self
Configuration of actor.
Sourcepub fn critic_config(self, critic_config: CriticConfig<Q::Config>) -> Self
pub fn critic_config(self, critic_config: CriticConfig<Q::Config>) -> Self
Configuration of critic.