Struct border_tch_agent::sac::SacConfig
source · pub struct SacConfig<Q, P>where
Q: SubModel2<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P: SubModel<Output = (Tensor, Tensor)>,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,{
pub device: Option<Device>,
/* private fields */
}Expand description
Constructs Sac.
Fields
device: Option<Device>Implementations
sourceimpl<Q, P> SacConfig<Q, P>where
Q: SubModel2<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P: SubModel<Output = (Tensor, Tensor)>,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
impl<Q, P> SacConfig<Q, P>where Q: SubModel2<Output = Tensor>, Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone, P: SubModel<Output = (Tensor, Tensor)>, P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
sourcepub fn n_updates_per_opt(self, v: usize) -> Self
pub fn n_updates_per_opt(self, v: usize) -> Self
Sets the numper of parameter update steps per optimization step.
sourcepub fn min_transitions_warmup(self, v: usize) -> Self
pub fn min_transitions_warmup(self, v: usize) -> Self
Interval before starting optimization.
sourcepub fn batch_size(self, v: usize) -> Self
pub fn batch_size(self, v: usize) -> Self
Batch size.
sourcepub fn discount_factor(self, v: f64) -> Self
pub fn discount_factor(self, v: f64) -> Self
Discount factor.
sourcepub fn ent_coef_mode(self, v: EntCoefMode) -> Self
pub fn ent_coef_mode(self, v: EntCoefMode) -> Self
SAC-alpha.
sourcepub fn replay_burffer_capacity(self, v: usize) -> Self
pub fn replay_burffer_capacity(self, v: usize) -> Self
Replay buffer capacity.
sourcepub fn reward_scale(self, v: f32) -> Self
pub fn reward_scale(self, v: f32) -> Self
Reward scale.
It works for obtaining target values, not the values in logs.
sourcepub fn critic_loss(self, v: CriticLoss) -> Self
pub fn critic_loss(self, v: CriticLoss) -> Self
Critic loss.
sourcepub fn actor_config(self, actor_config: ActorConfig<P::Config>) -> Self
pub fn actor_config(self, actor_config: ActorConfig<P::Config>) -> Self
Configuration of actor.
sourcepub fn critic_config(self, critic_config: CriticConfig<Q::Config>) -> Self
pub fn critic_config(self, critic_config: CriticConfig<Q::Config>) -> Self
Configuration of critic.