Utilities.
Structs
- Named
Tensors - Named tensors to send model parameters using a channel.
Enums
- Critic
Loss - Critic loss type.
Traits
- OutDim
- Interface for handling output dimensions.
Functions
- arrayd_
to_ tensor - Converts
ndarray::ArrayDtoTensor. - concat_
slices - Concatenates slices.
- param_
stats - Returns the mean and standard deviation of the parameters.
- quantile_
huber_ loss - Returns the quantile huber loss.
- tensor_
to_ arrayd - Converts
Tensortondarray::ArrayD. - track
- Apply soft update on variables.
- vec_
to_ tensor