Module util

Utilities.

Structs

NamedTensors
Named tensors to send model parameters using a channel.

Enums

CriticLoss
Critic loss type.

Traits

OutDim
Interface for handling output dimensions.

Functions

concat_slices
Concatenates slices.
param_stats
Returns the mean and standard deviation of the parameters.
quantile_huber_loss
Returns the quantile huber loss.
track
Apply soft update on variables.