Utilities.
Structs
- Named
Tensors - Named tensors to send model parameters using a channel.
Enums
- Critic
Loss - Critic loss type.
Traits
- OutDim
- Interface for handling output dimensions.
Functions
- concat_
slices - Concatenates slices.
- param_
stats - Returns the mean and standard deviation of the parameters.
- quantile_
huber_ loss - Returns the quantile huber loss.
- track
- Apply soft update on variables.